@@ -17,11 +17,13 @@ def ids(infile, outfile):
                 t = json.loads(line)
                 if 'id_str' in t:
                     click.echo(t['id_str'], file=outfile)
+                elif 'id' in t:
+                    click.echo(t['id'], file=outfile)
                 elif 'data' in t and 'id' in t['data']:
                     click.echo(t['data']['id'], file=outfile)
                 elif 'data' in t and type(t['data']) == list:
                     for tweet in t['data']:
-                        click.echo(tweet['id'])
+                        click.echo(tweet['id'], file=outfile)
                 else:
                     click.echo(f'Unexpected JSON on line {count}')
                     break
